@@ -5,16 +5,16 @@
 
 from __future__ import print_function
 
-import os
 import argparse
 import glob
+import os
+import pipes
 import subprocess
 import tempfile
-import pipes
 
-import pytest
-import psutil
 import grep_traceback
+import psutil
+import pytest
 
 import univention.testing.utils
 
@@ -59,6 +59,14 @@ def test_var_log_tracebacks_gz():
 	assert not_found, 'logfiles *.gz contain tracebacks'
 
 
+@pytest.mark.exposure('safe')
+def test_journallog_tracebacks():
+	proc = subprocess.Popen(['journalctl', '-o', 'cat'], stdout=subprocess.PIPE, text=True)
+	not_found = grep_traceback.main([proc.stdout], ignore_exceptions=grep_traceback.COMMON_EXCEPTIONS)
+	assert proc.wait() == 0
+	assert not_found, 'logfiles journalctl contain tracebacks'
+
+
 @pytest.mark.roles_not('domaincontroller_master')
 @pytest.mark.exposure('dangerous')
 # @pytest.mark.parametrize('testcase', [
